@@ -5,35 +5,36 @@ SPDX-License-Identifier: MIT-0
 import itertools
 import json
 import operator
-import re
 import sys
 from typing import List
 
+import regex as re
 import sarif_om as sarif
 from jschema_to_python.to_json import to_json
 from junit_xml import TestCase, TestSuite, to_xml_report_string
 
+from cfnlint.match import Match
+from cfnlint.rules import ParseError, RuleError, RulesCollection, TransformError
 from cfnlint.version import __version__
-from cfnlint.rules import Match, ParseError, RuleError, RulesCollection, TransformError
 
 Matches = List[Match]
 
 
 class color:
-    error = '\033[31m'
-    warning = '\033[33m'
-    informational = '\033[34m'
-    unknown = '\033[37m'
-    green = '\033[32m'
-    reset = '\033[0m'
-    bold_reset = '\033[1:0m'
-    underline_reset = '\033[4m'
+    error = "\033[31m"
+    warning = "\033[33m"
+    informational = "\033[34m"
+    unknown = "\033[37m"
+    green = "\033[32m"
+    reset = "\033[0m"
+    bold_reset = "\033[1:0m"
+    underline_reset = "\033[4m"
 
 
 def colored(s, c):
     """Takes in string s and outputs it with color"""
     if sys.stdout.isatty():
-        return f'{c}{s}{color.reset}'
+        return f"{c}{s}{color.reset}"
 
     return s
 
@@ -58,7 +59,7 @@ class BaseFormatter:
         for match in matches:
             output.append(self._format(match))
 
-        return '\n'.join(output)
+        return "\n".join(output)
 
 
 class Formatter(BaseFormatter):
@@ -66,7 +67,7 @@ class Formatter(BaseFormatter):
 
     def _format(self, match):
         """Format output"""
-        formatstr = '{0} {1}\n{2}:{3}:{4}\n'
+        formatstr = "{0} {1}\n{2}:{3}:{4}\n"
         return formatstr.format(
             match.rule.id,
             match.message,
@@ -81,7 +82,7 @@ class JUnitFormatter(BaseFormatter):
 
     def _failure_format(self, match):
         """Format output of a failure"""
-        formatstr = '{0} at {1}:{2}:{3}'
+        formatstr = "{0} at {1}:{2}:{3}"
         return formatstr.format(
             match.message, match.filename, match.linenumber, match.columnnumber
         )
@@ -101,18 +102,18 @@ class JUnitFormatter(BaseFormatter):
             if not rule.id in rules.used_rules:
                 if not rule.id:
                     continue
-                test_case = TestCase(name=f'{rule.id} {rule.shortdesc}')
+                test_case = TestCase(name=f"{rule.id} {rule.shortdesc}")
 
                 if rule.experimental:
                     test_case.add_skipped_info(
-                        message='Experimental rule - not enabled'
+                        message="Experimental rule - not enabled"
                     )
                 else:
-                    test_case.add_skipped_info(message='Ignored rule')
+                    test_case.add_skipped_info(message="Ignored rule")
                 test_cases.append(test_case)
             else:
                 test_case = TestCase(
-                    name=f'{rule.id} {rule.shortdesc}',
+                    name=f"{rule.id} {rule.shortdesc}",
                     allow_multiple_subelements=True,
                     url=rule.source_url,
                 )
@@ -124,7 +125,7 @@ class JUnitFormatter(BaseFormatter):
                         )
                 test_cases.append(test_case)
 
-        test_suite = TestSuite('CloudFormation Lint', test_cases)
+        test_suite = TestSuite("CloudFormation Lint", test_cases)
 
         return to_xml_report_string([test_suite], prettyprint=True)
 
@@ -140,28 +141,28 @@ class JsonFormatter(BaseFormatter):
         def default(self, o):
             if isinstance(o, Match):
                 return {
-                    'Rule': {
-                        'Id': o.rule.id,
-                        'Description': o.rule.description,
-                        'ShortDescription': o.rule.shortdesc,
-                        'Source': o.rule.source_url,
+                    "Rule": {
+                        "Id": o.rule.id,
+                        "Description": o.rule.description,
+                        "ShortDescription": o.rule.shortdesc,
+                        "Source": o.rule.source_url,
                     },
-                    'Location': {
-                        'Start': {
-                            'ColumnNumber': o.columnnumber,
-                            'LineNumber': o.linenumber,
+                    "Location": {
+                        "Start": {
+                            "ColumnNumber": o.columnnumber,
+                            "LineNumber": o.linenumber,
                         },
-                        'End': {
-                            'ColumnNumber': o.columnnumberend,
-                            'LineNumber': o.linenumberend,
+                        "End": {
+                            "ColumnNumber": o.columnnumberend,
+                            "LineNumber": o.linenumberend,
                         },
-                        'Path': getattr(o, 'path', None),
+                        "Path": getattr(o, "path", None),
                     },
-                    'Level': o.rule.severity.capitalize(),
-                    'Message': o.message,
-                    'Filename': o.filename,
+                    "Level": o.rule.severity.capitalize(),
+                    "Message": o.message,
+                    "Filename": o.filename,
                 }
-            return {f'__{o.__class__.__name__}__': o.__dict__}
+            return {f"__{o.__class__.__name__}__": o.__dict__}
 
     def print_matches(self, matches, rules=None, filenames=None):
         # JSON formatter outputs a single JSON object
@@ -173,7 +174,7 @@ class JsonFormatter(BaseFormatter):
             indent=4,
             cls=self.CustomEncoder,
             sort_keys=True,
-            separators=(',', ': '),
+            separators=(",", ": "),
         )
 
 
@@ -182,7 +183,7 @@ class QuietFormatter(BaseFormatter):
 
     def _format(self, match):
         """Format output"""
-        formatstr = '{0} {1}:{2}'
+        formatstr = "{0} {1}:{2}"
         return formatstr.format(match.rule, match.filename, match.linenumber)
 
 
@@ -191,7 +192,7 @@ class ParseableFormatter(BaseFormatter):
 
     def _format(self, match):
         """Format output"""
-        formatstr = '{0}:{1}:{2}:{3}:{4}:{5}:{6}'
+        formatstr = "{0}:{1}:{2}:{3}:{4}:{5}:{6}"
         return formatstr.format(
             match.filename,
             match.linenumber,
@@ -199,7 +200,7 @@ class ParseableFormatter(BaseFormatter):
             match.linenumberend,
             match.columnnumberend,
             match.rule.id,
-            re.sub(r'(\r*\n)+', ' ', match.message),
+            re.sub(r"(\r*\n)+", " ", match.message),
         )
 
 
@@ -208,11 +209,11 @@ class PrettyFormatter(BaseFormatter):
 
     def _format(self, match):
         """Format output"""
-        formatstr = '{0}{1}{2}'
-        pos = f'{match.linenumber}:{match.columnnumber}:'
+        formatstr = "{0}{1}{2}"
+        pos = f"{match.linenumber}:{match.columnnumber}:"
         return formatstr.format(
-            colored(f'{pos:20}', color.reset),
-            colored(f'{match.rule.id:10}', getattr(color, match.rule.severity.lower())),
+            colored(f"{pos:20}", color.reset),
+            colored(f"{match.rule.id:10}", getattr(color, match.rule.severity.lower())),
             match.message,
         )
 
@@ -220,15 +221,15 @@ class PrettyFormatter(BaseFormatter):
         results = self._format_matches(matches)
 
         results.append(
-            f'Cfn-lint scanned {colored(len(filenames), color.bold_reset)} templates against '
-            f'{colored(len(rules.used_rules), color.bold_reset)} rules and found '
+            f"Cfn-lint scanned {colored(len(filenames), color.bold_reset)} templates against "
+            f"{colored(len(rules.used_rules), color.bold_reset)} rules and found "
             f'{colored(len([i for i in matches if i.rule.severity.lower() == "error"]), color.error)} '
             f'errors, {colored(len([i for i in matches if i.rule.severity.lower() == "warning"]), color.warning)} '
-            f'warnings, and '
+            f"warnings, and "
             f'{colored(len([i for i in matches if i.rule.severity.lower() == "informational"]), color.informational)} '
-            f'informational violations'
+            f"informational violations"
         )
-        return '\n'.join(results)
+        return "\n".join(results)
 
     def _format_matches(self, matches):
         """Output all the matches"""
@@ -236,21 +237,21 @@ class PrettyFormatter(BaseFormatter):
 
         # This better be sorted
         for filename, file_matches in itertools.groupby(
-            matches, key=operator.attrgetter('filename')
+            matches, key=operator.attrgetter("filename")
         ):
-            levels = {'error': [], 'warning': [], 'informational': [], 'unknown': []}
+            levels = {"error": [], "warning": [], "informational": [], "unknown": []}
 
             output.append(colored(filename, color.underline_reset))
             for match in file_matches:
                 level = match.rule.severity.lower()
-                if level not in ['error', 'warning', 'informational']:
-                    level = 'unknown'
+                if level not in ["error", "warning", "informational"]:
+                    level = "unknown"
                 levels[level].append(match)
             for _, all_matches in levels.items():
                 for match in all_matches:
                     output.extend([self._format(match)])
 
-            output.append('')  # Newline after each group
+            output.append("")  # Newline after each group
 
         return output
 
@@ -265,20 +266,20 @@ class SARIFFormatter(BaseFormatter):
     https://docs.oasis-open.org/sarif/sarif/v2.1.0/csprd01/sarif-v2.1.0-csprd01.html
     """
 
-    schema = 'https://docs.oasis-open.org/sarif/sarif/v2.1.0/cos02/schemas/sarif-schema-2.1.0.json'
-    version = '2.1.0'
+    schema = "https://docs.oasis-open.org/sarif/sarif/v2.1.0/cos02/schemas/sarif-schema-2.1.0.json"
+    version = "2.1.0"
 
     # The spec defines error, note, warning, and none, see section 3.27.10.
     levelMap = {
-        'error': 'error',
-        'informational': 'note',
-        'warning': 'warning',
+        "error": "error",
+        "informational": "note",
+        "warning": "warning",
     }
 
-    uri_base_id = 'EXECUTIONROOT'
+    uri_base_id = "EXECUTIONROOT"
 
     def _to_sarif_level(self, severity):
-        return self.levelMap.get(severity, 'none')
+        return self.levelMap.get(severity, "none")
 
     def print_matches(self, matches, rules=None, filenames=None):
         """Output all the matches"""
@@ -330,7 +331,7 @@ class SARIFFormatter(BaseFormatter):
                 ),
                 help_uri=rules_map[rule_id].source_url
                 if rules_map[rule_id]
-                else 'https://github.com/aws-cloudformation/cfn-lint/blob/main/docs/rules.md',
+                else "https://github.com/aws-cloudformation/cfn-lint/blob/main/docs/rules.md",
             )
             for rule_id in matched_rules
         ]
@@ -338,15 +339,15 @@ class SARIFFormatter(BaseFormatter):
         run = sarif.Run(
             tool=sarif.Tool(
                 driver=sarif.ToolComponent(
-                    name='cfn-lint',
+                    name="cfn-lint",
                     short_description=sarif.MultiformatMessageString(
                         text=(
-                            'Validates AWS CloudFormation templates against'
-                            ' the resource specification and additional'
-                            ' checks.'
+                            "Validates AWS CloudFormation templates against"
+                            " the resource specification and additional"
+                            " checks."
                         )
                     ),
-                    information_uri='https://github.com/aws-cloudformation/cfn-lint',
+                    information_uri="https://github.com/aws-cloudformation/cfn-lint",
                     rules=rules,
                     version=__version__,
                 ),
@@ -354,7 +355,7 @@ class SARIFFormatter(BaseFormatter):
             original_uri_base_ids={
                 self.uri_base_id: sarif.ArtifactLocation(
                     description=sarif.MultiformatMessageString(
-                        'The directory in which cfn-lint was run.'
+                        "The directory in which cfn-lint was run."
                     )
                 )
             },
