@@ -14,14 +14,14 @@ import inspect
 import json
 import logging
 import os
-import re
 import sys
 from io import BytesIO
 from typing import Dict, List
 from urllib.request import Request, urlopen
 
+import regex as re
+
 from cfnlint.data import CloudSpecs
-from cfnlint.decode.node import dict_node, list_node, str_node
 
 LOGGER = logging.getLogger(__name__)
 
@@ -76,12 +76,11 @@ REGEX_IPV6 = re.compile(
     re.I | re.S,
 )
 REGEX_DYN_REF = re.compile(r"^.*{{resolve:.+}}.*$")
-REGEX_DYN_REF_SSM = re.compile(r"^.*{{resolve:ssm:[a-zA-Z0-9_\.\-/]+:\d+}}.*$")
+REGEX_DYN_REF_SSM = re.compile(r"^.*{{resolve:ssm:[a-zA-Z0-9_\.\-/]+(:\d+)?}}.*$")
 REGEX_DYN_REF_SSM_SECURE = re.compile(
-    r"^.*{{resolve:ssm-secure:[a-zA-Z0-9_\.\-/]+:\d+}}.*$"
+    r"^.*{{resolve:ssm-secure:[a-zA-Z0-9_\.\-/]+(:\d+)?}}.*$"
 )
 
-
 FUNCTIONS = [
     "Fn::Base64",
     "Fn::GetAtt",
@@ -110,6 +109,7 @@ FUNCTION_AND = "Fn::And"
 FUNCTION_OR = "Fn::Or"
 FUNCTION_NOT = "Fn::Not"
 FUNCTION_EQUALS = "Fn::Equals"
+FUNCTION_FOR_EACH = re.compile(r"^Fn::ForEach::[a-zA-Z0-9]+$")
 
 PSEUDOPARAMS = [
     "AWS::AccountId",
@@ -542,29 +542,6 @@ def load_plugins(directory):
     return result
 
 
-def convert_dict(template, start_mark=(0, 0), end_mark=(0, 0)):
-    """Convert dict to template"""
-    if isinstance(template, dict):
-        if not isinstance(template, dict_node):
-            template = dict_node(template, start_mark, end_mark)
-        for k, v in template.copy().items():
-            k_start_mark = start_mark
-            k_end_mark = end_mark
-            if isinstance(k, str_node):
-                k_start_mark = k.start_mark
-                k_end_mark = k.end_mark
-            new_k = str_node(k, k_start_mark, k_end_mark)
-            del template[k]
-            template[new_k] = convert_dict(v, k_start_mark, k_end_mark)
-    elif isinstance(template, list):
-        if not isinstance(template, list_node):
-            template = list_node(template, start_mark, end_mark)
-        for i, v in enumerate(template):
-            template[i] = convert_dict(v, start_mark, end_mark)
-
-    return template
-
-
 def override_specs(override_spec_file):
     """Override specs file"""
     try:
